@@ -17,7 +17,6 @@
 #'   Sheets (`calligrasheets`).
 #'
 #' @param x A path to the Excel (xls/xlsx) file or Workbook object.
-#' @param file Deprecated
 #' @param interactive If `FALSE` will throw a warning and not open the path.
 #'   This can be manually set to `TRUE`, otherwise when `NA` (default) uses the
 #'   value returned from [base::interactive()]
@@ -36,17 +35,13 @@
 #'   xl_open(wb)
 #' }
 #' }
-xl_open <- function(x, file, interactive = NA) {
-  if (!missing(file))  {
-    warning("xl_open(file = .) is deprecated.  Use xl_open(x = .) instead")
-    x <- file
-  }
+xl_open <- function(x, interactive = NA) {
   UseMethod("xl_open")
 }
 
 #' @rdname xl_open
 #' @export
-xl_open.wbWorkbook <- function(x, file, interactive = NA) {
+xl_open.wbWorkbook <- function(x, interactive = NA) {
   stopifnot(R6::is.R6(x))
   has_macros <- isTRUE(length(x$vbaProject) > 0)
   xl_open(x$clone()$save(temp_xlsx(macros = has_macros))$path, interactive = interactive)
@@ -54,7 +49,7 @@ xl_open.wbWorkbook <- function(x, file, interactive = NA) {
 
 #' @rdname xl_open
 #' @export
-xl_open.default <- function(x, file, interactive = NA) {
+xl_open.default <- function(x, interactive = NA) {
   stopifnot(file.exists(x))
 
   # nocov start
