@@ -289,7 +289,7 @@ bool is_double(std::string x) {
 
   res = R_strtod(x.c_str(), &endp);
 
-  if (isBlankString(endp) && isfinite(res)) {
+  if (isBlankString(endp) && std::isfinite(res)) {
     return 1;
   }
 
