@@ -24,7 +24,7 @@ test_that("Maintaining Named Regions on Load", {
   out_file <- temp_xlsx()
   wb_save(wb, out_file, overwrite = TRUE)
 
-  expect_equal(object = get_named_regions(wb), expected = get_named_regions(out_file))
+  expect_equal(object = wb_get_named_regions(wb), expected = wb_get_named_regions(out_file))
 
   df1 <- read_xlsx(wb, namedRegion = "iris")
   df2 <- read_xlsx(out_file, namedRegion = "iris")
@@ -115,7 +115,7 @@ test_that("Correctly Loading Named Regions Created in Excel", {
 test_that("Load names from an Excel file with funky non-region names", {
   filename <- system.file("extdata", "namedRegions2.xlsx", package = "openxlsx2")
   wb <- wb_load(filename)
-  dn <- get_named_regions(wb)
+  dn <- wb_get_named_regions(wb)
 
   expect_equal(
     head(dn$name, 5),
@@ -129,7 +129,7 @@ test_that("Load names from an Excel file with funky non-region names", {
   )
   expect_equal(dn$coords, c(rep("", 26), "B3", "B4", "B4", "B3"))
 
-  dn2 <- get_named_regions(filename)
+  dn2 <- wb_get_named_regions(filename)
   expect_equal(dn, dn2)
 })
 
@@ -162,9 +162,9 @@ test_that("Missing rows in named regions", {
   ## iris2 region is rows 1:7 & cols 1:2
 
   ## row 6 columns 1 & 2 are blank
-  expect_equal(get_named_regions(wb)$name, c("iris", "iris2"))
-  expect_equal(get_named_regions(wb)$sheets, c("Sheet 1", "Sheet 1"))
-  expect_equal(get_named_regions(wb)$coords, c("A1:B6", "A1:B7"))
+  expect_equal(wb_get_named_regions(wb)$name, c("iris", "iris2"))
+  expect_equal(wb_get_named_regions(wb)$sheets, c("Sheet 1", "Sheet 1"))
+  expect_equal(wb_get_named_regions(wb)$coords, c("A1:B6", "A1:B7"))
 
   ######################################################################## from Workbook
 
@@ -235,9 +235,9 @@ test_that("Missing columns in named regions", {
   ## iris2 region is rows 1:5 & cols 1:3
 
   ## row 6 columns 1 & 2 are blank
-  expect_equal(get_named_regions(wb)$name, c("iris", "iris2"), ignore_attr = TRUE)
-  expect_equal(get_named_regions(wb)$sheets, c("Sheet 1", "Sheet 1"))
-  expect_equal(get_named_regions(wb)$coords, c("A1:B5", "A1:C5"))
+  expect_equal(wb_get_named_regions(wb)$name, c("iris", "iris2"), ignore_attr = TRUE)
+  expect_equal(wb_get_named_regions(wb)$sheets, c("Sheet 1", "Sheet 1"))
+  expect_equal(wb_get_named_regions(wb)$coords, c("A1:B5", "A1:C5"))
 
   ######################################################################## from Workbook
 
@@ -299,12 +299,12 @@ test_that("Matching Substrings breaks reading named regions", {
 
   wb_save(wb, temp_file)
 
-  r1 <- get_named_regions(wb)
+  r1 <- wb_get_named_regions(wb)
   expect_equal(r1$sheets, c("table", "table", "table2", "table2"))
   expect_equal(r1$coords, c("C12:G18", "I3:M6", "E24:P30", "O12:Z15"))
   expect_equal(r1$name, c("t", "t1", "t2", "t22"))
 
-  r2 <- get_named_regions(temp_file)
+  r2 <- wb_get_named_regions(temp_file)
   expect_equal(r2$sheets, c("table", "table", "table2", "table2"))
   expect_equal(r1$coords, c("C12:G18", "I3:M6", "E24:P30", "O12:Z15"))
   expect_equal(r2$name, c("t", "t1", "t2", "t22"))
@@ -350,10 +350,10 @@ test_that("Overwrite and delete named regions", {
   temp_file <- temp_xlsx()
 
   wb <- wb_workbook()
-  expect_null(get_named_regions(wb))
+  expect_null(wb_get_named_regions(wb))
 
   wb$add_worksheet("Sheet 1")
-  expect_null(get_named_regions(wb))
+  expect_null(wb_get_named_regions(wb))
 
   ## create region
   wb$add_data(1, iris[1:11, ], startCol = 1, startRow = 1, name = "iris")
@@ -366,7 +366,7 @@ test_that("Overwrite and delete named regions", {
     local  = 0,
     sheet  = 1L
   )
-  expect_identical(get_named_regions(wb), exp)
+  expect_identical(wb_get_named_regions(wb), exp)
 
   # no overwrite
   expect_error(wb$add_data(1, iris[1:11, ], startCol = 1, startRow = 1, name = "iris"))
@@ -389,28 +389,18 @@ test_that("Overwrite and delete named regions", {
   )
 
   # check modification
-  expect_identical(get_named_regions(wb), exp)
+  expect_identical(wb_get_named_regions(wb), exp)
 
   # delete name region
   wb$remove_named_region(name = "iris")
-  expect_false("iris" %in% get_named_regions(wb)$name)
+  expect_false("iris" %in% wb_get_named_regions(wb)$name)
 
   wb$add_named_region(1, name = "iris", rows = 1:5, cols = 1:2)
-  expect_identical(get_named_regions(wb), exp)
+  expect_identical(wb_get_named_regions(wb), exp)
 
   # removing a worksheet removes the named region as well
   wb <- wb_remove_worksheet(wb, 1)
-  expect_null(get_named_regions(wb))
-})
-
-
-test_that("deprecation test", {
-
-    filename <- system.file("extdata", "namedRegions3.xlsx", package = "openxlsx2")
-    expect_warning(wb_to_df(filename, definedName = "MyRange"),
-                   "wb_to_df(definedName = .) is deprecated.  Use wb_to_df(named_region = .) instead",
-                   fixed = TRUE)
-
+  expect_null(wb_get_named_regions(wb))
 })
 
 test_that("load table", {
@@ -429,7 +419,7 @@ test_that("load table", {
     cols = seq_along(iris)
   )
 
-  expect_equal(c("iris", "iris_tab"), get_named_regions(wb)$name)
+  expect_equal(c("iris", "iris_tab"), wb_get_named_regions(wb)$name)
 
   expect_equal(
     wb_to_df(wb, named_region = "iris_tab"),
@@ -437,3 +427,15 @@ test_that("load table", {
   )
 
 })
+
+test_that("get_named_regions is deprecated", {
+
+  wb <- wb_workbook()$add_worksheet()$add_named_region(
+    name = "named_region",
+    rows = 5:7,
+    cols = 6:8
+  )
+
+  expect_warning(get_named_regions(wb), "deprecated")
+
+})
